#!/bin/bash
#
# Copyright (c) 2006 SUSE Linux Products GmbH Nuernberg, Germany.
#
# Author: Stephan Kulow   <coolo@suse.de>
#

#
# check if we are started as root
# only one of UID and USER must be set correctly
#
if test "$UID" != 0 -a "$USER" != root; then
    echo "You must be root to start $0."
    exit 1
fi

#
# check for sysconfig/displaymanager or rc.config
#
test -f /etc/sysconfig/displaymanager && source /etc/sysconfig/displaymanager
test -f /etc/sysconfig/security       && source /etc/sysconfig/security
test -f /etc/sysconfig/language       && source /etc/sysconfig/language

#
# source /etc/profile to get $kdedir
#
kdedir="/opt/kde3"
kdmdir="/var/adm/kdm"

# check for write permissions
[ -w ${kdmdir} ] || mkdir -p ${kdmdir}
[ -w ${kdmdir} ] || exit

#
# Set Style of Shutdown
#
ECHO_MODE="OneStar"
ALLOW_ROOT_LOGIN="true"
case "$DISPLAYMANAGER_SHUTDOWN" in
    all|ALL|All)
         DISPLAYMANAGER_SHUTDOWN=All;;
    none|NONE|None)
         DISPLAYMANAGER_SHUTDOWN=None;;
    auto|Auto|AUTO)
      case "$PERMISSION_SECURITY" in
	*easy*)
	     DISPLAYMANAGER_SHUTDOWN=All
             ;;
        *paranoid*)
             ECHO_MODE="NoEcho"
             ALLOW_ROOT_LOGIN="false"
	     DISPLAYMANAGER_SHUTDOWN=Root
             ;;
	*)
	     DISPLAYMANAGER_SHUTDOWN=Root
	     ;;
      esac
      ;;
    * )
        DISPLAYMANAGER_SHUTDOWN=Root;;
esac

(
echo "[X-*-Greeter]"
if [ -n "$KDM_USERS" ]; then
  echo "ShowUsers=Selected"
  echo -n "SelectedUsers="
  echo ${KDM_USERS}|sed -e 's@ [ ]*@ @g' -e 's@ @,@g'
else
  echo "ShowUsers=NotHidden"
fi
if [ "$DISPLAYMANAGER_AD_INTEGRATION" = "yes" ]; then
  echo "PluginsLogin=winbind"
fi
if [ -n "$DISPLAYMANAGER_KDM_THEME" -a -d "/opt/kde3/share/apps/kdm/themes/$DISPLAYMANAGER_KDM_THEME" ]; then
  echo "Theme=/opt/kde3/share/apps/kdm/themes/$DISPLAYMANAGER_KDM_THEME"
  echo "UseTheme=true"
  echo "UseBackground=false"
else
  echo "UseTheme=false"
  echo "UseBackground=true"
fi
# kdm has en_US as default instead of simply reading LC_LANG :(
echo "Language="

echo "[Xdmcp]"
if [ "$DISPLAYMANAGER_REMOTE_ACCESS" = "yes" ]; then
  echo "Enable=true"
else
  echo "Enable=false"
fi

echo "[X-:0-Core]"
if [ "$DISPLAYMANAGER_AUTOLOGIN" ]; then
  echo "AutoLoginEnable=true"
  echo "AutoLoginUser=${DISPLAYMANAGER_AUTOLOGIN}"
else
  echo "AutoLoginEnable=false"
fi
if [ "$DISPLAYMANAGER_XSERVER_TCP_PORT_6000_OPEN" = "yes" ]; then
  echo "ServerArgsLocal=$DISPLAYMANAGER_SERVERARGSLOCAL"
else
  echo "ServerArgsLocal=-nolisten tcp $DISPLAYMANAGER_SERVERARGSLOCAL"
fi
if [ "$DISPLAYMANAGER_PASSWORD_LESS_LOGIN" = "yes" ]; then
   echo "NoPassEnable=true"
   echo "NoPassAllUsers=true"
else
   echo "NoPassEnable=false"
   echo "NoPassAllUsers=false"
fi

echo "[X-:*-Core]"
echo "AllowShutdown=${DISPLAYMANAGER_SHUTDOWN}"
echo "AllowRootLogin=${ALLOW_ROOT_LOGIN}"
echo "AllowNullPasswd=${ALLOW_ROOT_LOGIN}"

echo "[X-*-Core]"

if test "$DISPLAYMANAGER_ROOT_LOGIN_REMOTE" = "yes"; then
    echo "AllowRootLogin=true"
else
    echo "AllowRootLogin=false"
fi

case "$DISPLAYMANAGER_XSERVER" in
   Xgl)
	xgl=`type -p Xgl`
	echo "ServerCmd=$xgl $DISPLAYMANAGER_XGL_OPTS -br"
        echo "ServerTimeout=50"
        ;;
   Xorg)
        xorg=`type -p Xorg`
	echo "ServerCmd=$xorg -br"
	;;
   *)
	echo "#Unknown X server - leaving X"
	;;
esac

echo "[General]"
if [ "$DISPLAYMANAGER_STARTS_XSERVER" != "yes" ]; then
  echo "StaticServers="
fi

) > ${kdmdir}/kdmrc.sysconfig

